@@ -2,18 +2,17 @@ from .utils import check_valid_session
 
 
 class SessionsMixin:
-
     @check_valid_session
     def put_sessions(self):
-        return self.put('sessions')
+        return self.put("sessions")
 
     @check_valid_session
     def get_sessions_userinfo(self):
-        return self.get('sessions/userInfo')
+        return self.get("sessions/userInfo")
 
     @check_valid_session
     def get_sessions(self):
-        return self.get('sessions')
+        return self.get("sessions")
 
     # "Friendly" method aliases
     def extend_session(self):
@@ -24,4 +23,3 @@ class SessionsMixin:
 
     def get_session_info(self):
         return self.get_sessions()
-
